/* Exports.c generated by valac 0.56.19, the Vala compiler
 * generated from Exports.vala, do not modify */

/*
* Copyright (c) 2020-2026 (https://github.com/phase1geo/Minder)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301 USA
*
* Authored by: Trevor Williams <phase1geo@gmail.com>
*/

#include <glib-object.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gstdio.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_EXPORTS (exports_get_type ())
#define EXPORTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORTS, Exports))
#define EXPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORTS, ExportsClass))
#define IS_EXPORTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORTS))
#define IS_EXPORTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORTS))
#define EXPORTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORTS, ExportsClass))

typedef struct _Exports Exports;
typedef struct _ExportsClass ExportsClass;
typedef struct _ExportsPrivate ExportsPrivate;

#define TYPE_EXPORT (export_get_type ())
#define EXPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT, Export))
#define EXPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT, ExportClass))
#define IS_EXPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT))
#define IS_EXPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT))
#define EXPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT, ExportClass))

typedef struct _Export Export;
typedef struct _ExportClass ExportClass;
#define _g_array_unref0(var) ((var == NULL) ? NULL : (var = (g_array_unref (var), NULL)))

#define TYPE_EXPORT_CSV (export_csv_get_type ())
#define EXPORT_CSV(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_CSV, ExportCSV))
#define EXPORT_CSV_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_CSV, ExportCSVClass))
#define IS_EXPORT_CSV(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_CSV))
#define IS_EXPORT_CSV_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_CSV))
#define EXPORT_CSV_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_CSV, ExportCSVClass))

typedef struct _ExportCSV ExportCSV;
typedef struct _ExportCSVClass ExportCSVClass;
#define _export_unref0(var) ((var == NULL) ? NULL : (var = (export_unref (var), NULL)))

#define TYPE_EXPORT_FILE_SYSTEM (export_file_system_get_type ())
#define EXPORT_FILE_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_FILE_SYSTEM, ExportFileSystem))
#define EXPORT_FILE_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_FILE_SYSTEM, ExportFileSystemClass))
#define IS_EXPORT_FILE_SYSTEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_FILE_SYSTEM))
#define IS_EXPORT_FILE_SYSTEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_FILE_SYSTEM))
#define EXPORT_FILE_SYSTEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_FILE_SYSTEM, ExportFileSystemClass))

typedef struct _ExportFileSystem ExportFileSystem;
typedef struct _ExportFileSystemClass ExportFileSystemClass;

#define TYPE_EXPORT_FREEMIND (export_freemind_get_type ())
#define EXPORT_FREEMIND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_FREEMIND, ExportFreemind))
#define EXPORT_FREEMIND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_FREEMIND, ExportFreemindClass))
#define IS_EXPORT_FREEMIND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_FREEMIND))
#define IS_EXPORT_FREEMIND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_FREEMIND))
#define EXPORT_FREEMIND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_FREEMIND, ExportFreemindClass))

typedef struct _ExportFreemind ExportFreemind;
typedef struct _ExportFreemindClass ExportFreemindClass;

#define TYPE_EXPORT_FREEPLANE (export_freeplane_get_type ())
#define EXPORT_FREEPLANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_FREEPLANE, ExportFreeplane))
#define EXPORT_FREEPLANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_FREEPLANE, ExportFreeplaneClass))
#define IS_EXPORT_FREEPLANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_FREEPLANE))
#define IS_EXPORT_FREEPLANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_FREEPLANE))
#define EXPORT_FREEPLANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_FREEPLANE, ExportFreeplaneClass))

typedef struct _ExportFreeplane ExportFreeplane;
typedef struct _ExportFreeplaneClass ExportFreeplaneClass;

#define TYPE_EXPORT_IMAGE (export_image_get_type ())
#define EXPORT_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_IMAGE, ExportImage))
#define EXPORT_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_IMAGE, ExportImageClass))
#define IS_EXPORT_IMAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_IMAGE))
#define IS_EXPORT_IMAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_IMAGE))
#define EXPORT_IMAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_IMAGE, ExportImageClass))

typedef struct _ExportImage ExportImage;
typedef struct _ExportImageClass ExportImageClass;

#define TYPE_EXPORT_MARKDOWN (export_markdown_get_type ())
#define EXPORT_MARKDOWN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_MARKDOWN, ExportMarkdown))
#define EXPORT_MARKDOWN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_MARKDOWN, ExportMarkdownClass))
#define IS_EXPORT_MARKDOWN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_MARKDOWN))
#define IS_EXPORT_MARKDOWN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_MARKDOWN))
#define EXPORT_MARKDOWN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_MARKDOWN, ExportMarkdownClass))

typedef struct _ExportMarkdown ExportMarkdown;
typedef struct _ExportMarkdownClass ExportMarkdownClass;

#define TYPE_EXPORT_MERMAID (export_mermaid_get_type ())
#define EXPORT_MERMAID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_MERMAID, ExportMermaid))
#define EXPORT_MERMAID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_MERMAID, ExportMermaidClass))
#define IS_EXPORT_MERMAID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_MERMAID))
#define IS_EXPORT_MERMAID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_MERMAID))
#define EXPORT_MERMAID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_MERMAID, ExportMermaidClass))

typedef struct _ExportMermaid ExportMermaid;
typedef struct _ExportMermaidClass ExportMermaidClass;

#define TYPE_EXPORT_OPML (export_opml_get_type ())
#define EXPORT_OPML(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_OPML, ExportOPML))
#define EXPORT_OPML_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_OPML, ExportOPMLClass))
#define IS_EXPORT_OPML(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_OPML))
#define IS_EXPORT_OPML_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_OPML))
#define EXPORT_OPML_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_OPML, ExportOPMLClass))

typedef struct _ExportOPML ExportOPML;
typedef struct _ExportOPMLClass ExportOPMLClass;

#define TYPE_EXPORT_ORG_MODE (export_org_mode_get_type ())
#define EXPORT_ORG_MODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_ORG_MODE, ExportOrgMode))
#define EXPORT_ORG_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_ORG_MODE, ExportOrgModeClass))
#define IS_EXPORT_ORG_MODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_ORG_MODE))
#define IS_EXPORT_ORG_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_ORG_MODE))
#define EXPORT_ORG_MODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_ORG_MODE, ExportOrgModeClass))

typedef struct _ExportOrgMode ExportOrgMode;
typedef struct _ExportOrgModeClass ExportOrgModeClass;

#define TYPE_EXPORT_OUTLINER (export_outliner_get_type ())
#define EXPORT_OUTLINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_OUTLINER, ExportOutliner))
#define EXPORT_OUTLINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_OUTLINER, ExportOutlinerClass))
#define IS_EXPORT_OUTLINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_OUTLINER))
#define IS_EXPORT_OUTLINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_OUTLINER))
#define EXPORT_OUTLINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_OUTLINER, ExportOutlinerClass))

typedef struct _ExportOutliner ExportOutliner;
typedef struct _ExportOutlinerClass ExportOutlinerClass;

#define TYPE_EXPORT_PDF (export_pdf_get_type ())
#define EXPORT_PDF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_PDF, ExportPDF))
#define EXPORT_PDF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_PDF, ExportPDFClass))
#define IS_EXPORT_PDF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_PDF))
#define IS_EXPORT_PDF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_PDF))
#define EXPORT_PDF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_PDF, ExportPDFClass))

typedef struct _ExportPDF ExportPDF;
typedef struct _ExportPDFClass ExportPDFClass;

#define TYPE_EXPORT_PNG (export_png_get_type ())
#define EXPORT_PNG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_PNG, ExportPNG))
#define EXPORT_PNG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_PNG, ExportPNGClass))
#define IS_EXPORT_PNG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_PNG))
#define IS_EXPORT_PNG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_PNG))
#define EXPORT_PNG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_PNG, ExportPNGClass))

typedef struct _ExportPNG ExportPNG;
typedef struct _ExportPNGClass ExportPNGClass;

#define TYPE_EXPORT_PLANT_UML (export_plant_uml_get_type ())
#define EXPORT_PLANT_UML(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_PLANT_UML, ExportPlantUML))
#define EXPORT_PLANT_UML_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_PLANT_UML, ExportPlantUMLClass))
#define IS_EXPORT_PLANT_UML(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_PLANT_UML))
#define IS_EXPORT_PLANT_UML_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_PLANT_UML))
#define EXPORT_PLANT_UML_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_PLANT_UML, ExportPlantUMLClass))

typedef struct _ExportPlantUML ExportPlantUML;
typedef struct _ExportPlantUMLClass ExportPlantUMLClass;

#define TYPE_EXPORT_PORTABLE_MINDER (export_portable_minder_get_type ())
#define EXPORT_PORTABLE_MINDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_PORTABLE_MINDER, ExportPortableMinder))
#define EXPORT_PORTABLE_MINDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_PORTABLE_MINDER, ExportPortableMinderClass))
#define IS_EXPORT_PORTABLE_MINDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_PORTABLE_MINDER))
#define IS_EXPORT_PORTABLE_MINDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_PORTABLE_MINDER))
#define EXPORT_PORTABLE_MINDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_PORTABLE_MINDER, ExportPortableMinderClass))

typedef struct _ExportPortableMinder ExportPortableMinder;
typedef struct _ExportPortableMinderClass ExportPortableMinderClass;

#define TYPE_EXPORT_SVG (export_svg_get_type ())
#define EXPORT_SVG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_SVG, ExportSVG))
#define EXPORT_SVG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_SVG, ExportSVGClass))
#define IS_EXPORT_SVG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_SVG))
#define IS_EXPORT_SVG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_SVG))
#define EXPORT_SVG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_SVG, ExportSVGClass))

typedef struct _ExportSVG ExportSVG;
typedef struct _ExportSVGClass ExportSVGClass;

#define TYPE_EXPORT_TEXT (export_text_get_type ())
#define EXPORT_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_TEXT, ExportText))
#define EXPORT_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_TEXT, ExportTextClass))
#define IS_EXPORT_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_TEXT))
#define IS_EXPORT_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_TEXT))
#define EXPORT_TEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_TEXT, ExportTextClass))

typedef struct _ExportText ExportText;
typedef struct _ExportTextClass ExportTextClass;

#define TYPE_EXPORT_WEB_P (export_web_p_get_type ())
#define EXPORT_WEB_P(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_WEB_P, ExportWebP))
#define EXPORT_WEB_P_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_WEB_P, ExportWebPClass))
#define IS_EXPORT_WEB_P(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_WEB_P))
#define IS_EXPORT_WEB_P_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_WEB_P))
#define EXPORT_WEB_P_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_WEB_P, ExportWebPClass))

typedef struct _ExportWebP ExportWebP;
typedef struct _ExportWebPClass ExportWebPClass;

#define TYPE_EXPORT_XMIND8 (export_xmind8_get_type ())
#define EXPORT_XMIND8(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_XMIND8, ExportXMind8))
#define EXPORT_XMIND8_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_XMIND8, ExportXMind8Class))
#define IS_EXPORT_XMIND8(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_XMIND8))
#define IS_EXPORT_XMIND8_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_XMIND8))
#define EXPORT_XMIND8_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_XMIND8, ExportXMind8Class))

typedef struct _ExportXMind8 ExportXMind8;
typedef struct _ExportXMind8Class ExportXMind8Class;

#define TYPE_EXPORT_XMIND2021 (export_xmind2021_get_type ())
#define EXPORT_XMIND2021(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_XMIND2021, ExportXMind2021))
#define EXPORT_XMIND2021_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_XMIND2021, ExportXMind2021Class))
#define IS_EXPORT_XMIND2021(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_XMIND2021))
#define IS_EXPORT_XMIND2021_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_XMIND2021))
#define EXPORT_XMIND2021_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_XMIND2021, ExportXMind2021Class))

typedef struct _ExportXMind2021 ExportXMind2021;
typedef struct _ExportXMind2021Class ExportXMind2021Class;

#define TYPE_EXPORT_YED (export_yed_get_type ())
#define EXPORT_YED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_YED, ExportYed))
#define EXPORT_YED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_YED, ExportYedClass))
#define IS_EXPORT_YED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_YED))
#define IS_EXPORT_YED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_YED))
#define EXPORT_YED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_YED, ExportYedClass))

typedef struct _ExportYed ExportYed;
typedef struct _ExportYedClass ExportYedClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _xmlFreeDoc0(var) ((var == NULL) ? NULL : (var = (xmlFreeDoc (var), NULL)))
typedef struct _ParamSpecExports ParamSpecExports;

struct _Exports {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ExportsPrivate * priv;
};

struct _ExportsClass {
	GTypeClass parent_class;
	void (*finalize) (Exports *self);
};

struct _ExportsPrivate {
	GArray* _exports;
};

struct _ParamSpecExports {
	GParamSpec parent_instance;
};

static gint Exports_private_offset;
static gpointer exports_parent_class = NULL;
VALA_EXTERN gchar* minder_version;

VALA_EXTERN gpointer exports_ref (gpointer instance);
VALA_EXTERN void exports_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_exports (const gchar* name,
                                const gchar* nick,
                                const gchar* blurb,
                                GType object_type,
                                GParamFlags flags);
VALA_EXTERN void value_set_exports (GValue* value,
                        gpointer v_object);
VALA_EXTERN void value_take_exports (GValue* value,
                         gpointer v_object);
VALA_EXTERN gpointer value_get_exports (const GValue* value);
VALA_EXTERN GType exports_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Exports, exports_unref)
VALA_EXTERN gpointer export_ref (gpointer instance);
VALA_EXTERN void export_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_export (const gchar* name,
                               const gchar* nick,
                               const gchar* blurb,
                               GType object_type,
                               GParamFlags flags);
VALA_EXTERN void value_set_export (GValue* value,
                       gpointer v_object);
VALA_EXTERN void value_take_export (GValue* value,
                        gpointer v_object);
VALA_EXTERN gpointer value_get_export (const GValue* value);
VALA_EXTERN GType export_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Export, export_unref)
VALA_EXTERN Exports* exports_new (gboolean save_settings);
VALA_EXTERN Exports* exports_construct (GType object_type,
                            gboolean save_settings);
static void _export_unref0_ (gpointer var);
static void _vala_Export_free_function_content_of (gpointer data);
static void exports_add (Exports* self,
                  Export* export,
                  gboolean save_settings);
VALA_EXTERN ExportCSV* export_csv_new (void);
VALA_EXTERN ExportCSV* export_csv_construct (GType object_type);
VALA_EXTERN GType export_csv_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportCSV, export_unref)
VALA_EXTERN ExportFileSystem* export_file_system_new (void);
VALA_EXTERN ExportFileSystem* export_file_system_construct (GType object_type);
VALA_EXTERN GType export_file_system_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportFileSystem, export_unref)
VALA_EXTERN ExportFreemind* export_freemind_new (void);
VALA_EXTERN ExportFreemind* export_freemind_construct (GType object_type);
VALA_EXTERN GType export_freemind_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportFreemind, export_unref)
VALA_EXTERN ExportFreeplane* export_freeplane_new (void);
VALA_EXTERN ExportFreeplane* export_freeplane_construct (GType object_type);
VALA_EXTERN GType export_freeplane_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportFreeplane, export_unref)
VALA_EXTERN ExportImage* export_image_new (const gchar* type,
                               const gchar* label,
                               gchar** extensions,
                               gint extensions_length1);
VALA_EXTERN ExportImage* export_image_construct (GType object_type,
                                     const gchar* type,
                                     const gchar* label,
                                     gchar** extensions,
                                     gint extensions_length1);
VALA_EXTERN GType export_image_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportImage, export_unref)
VALA_EXTERN ExportMarkdown* export_markdown_new (void);
VALA_EXTERN ExportMarkdown* export_markdown_construct (GType object_type);
VALA_EXTERN GType export_markdown_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportMarkdown, export_unref)
VALA_EXTERN ExportMermaid* export_mermaid_new (void);
VALA_EXTERN ExportMermaid* export_mermaid_construct (GType object_type);
VALA_EXTERN GType export_mermaid_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportMermaid, export_unref)
VALA_EXTERN ExportOPML* export_opml_new (void);
VALA_EXTERN ExportOPML* export_opml_construct (GType object_type);
VALA_EXTERN GType export_opml_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportOPML, export_unref)
VALA_EXTERN ExportOrgMode* export_org_mode_new (void);
VALA_EXTERN ExportOrgMode* export_org_mode_construct (GType object_type);
VALA_EXTERN GType export_org_mode_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportOrgMode, export_unref)
VALA_EXTERN ExportOutliner* export_outliner_new (void);
VALA_EXTERN ExportOutliner* export_outliner_construct (GType object_type);
VALA_EXTERN GType export_outliner_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportOutliner, export_unref)
VALA_EXTERN ExportPDF* export_pdf_new (void);
VALA_EXTERN ExportPDF* export_pdf_construct (GType object_type);
VALA_EXTERN GType export_pdf_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportPDF, export_unref)
VALA_EXTERN ExportPNG* export_png_new (void);
VALA_EXTERN ExportPNG* export_png_construct (GType object_type);
VALA_EXTERN GType export_png_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportPNG, export_unref)
VALA_EXTERN ExportPlantUML* export_plant_uml_new (void);
VALA_EXTERN ExportPlantUML* export_plant_uml_construct (GType object_type);
VALA_EXTERN GType export_plant_uml_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportPlantUML, export_unref)
VALA_EXTERN ExportPortableMinder* export_portable_minder_new (void);
VALA_EXTERN ExportPortableMinder* export_portable_minder_construct (GType object_type);
VALA_EXTERN GType export_portable_minder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportPortableMinder, export_unref)
VALA_EXTERN ExportSVG* export_svg_new (void);
VALA_EXTERN ExportSVG* export_svg_construct (GType object_type);
VALA_EXTERN GType export_svg_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportSVG, export_unref)
VALA_EXTERN ExportText* export_text_new (void);
VALA_EXTERN ExportText* export_text_construct (GType object_type);
VALA_EXTERN GType export_text_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportText, export_unref)
VALA_EXTERN ExportWebP* export_web_p_new (void);
VALA_EXTERN ExportWebP* export_web_p_construct (GType object_type);
VALA_EXTERN GType export_web_p_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportWebP, export_unref)
VALA_EXTERN ExportXMind8* export_xmind8_new (void);
VALA_EXTERN ExportXMind8* export_xmind8_construct (GType object_type);
VALA_EXTERN GType export_xmind8_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportXMind8, export_unref)
VALA_EXTERN ExportXMind2021* export_xmind2021_new (void);
VALA_EXTERN ExportXMind2021* export_xmind2021_construct (GType object_type);
VALA_EXTERN GType export_xmind2021_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportXMind2021, export_unref)
VALA_EXTERN ExportYed* export_yed_new (void);
VALA_EXTERN ExportYed* export_yed_construct (GType object_type);
VALA_EXTERN GType export_yed_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ExportYed, export_unref)
static void ___lambda243_ (Exports* self);
VALA_EXTERN void exports_save (Exports* self);
static void ____lambda243__export_settings_changed (Export* _sender,
                                             gpointer self);
VALA_EXTERN gint exports_length (Exports* self);
VALA_EXTERN Export* exports_index (Exports* self,
                       gint idx);
VALA_EXTERN Export* exports_get_by_name (Exports* self,
                             const gchar* name);
VALA_EXTERN const gchar* export_get_name (Export* self);
VALA_EXTERN gint exports_get_index_by_name (Exports* self,
                                const gchar* name);
static gchar* exports_settings_file (Exports* self,
                              gboolean make_dir);
VALA_EXTERN xmlNode* export_save (Export* self);
VALA_EXTERN void exports_load (Exports* self);
VALA_EXTERN void export_load (Export* self,
                  xmlNode* node);
static void exports_finalize (Exports * obj);
static GType exports_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
exports_get_instance_private (Exports* self)
{
	return G_STRUCT_MEMBER_P (self, Exports_private_offset);
}

static void
_export_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (export_unref (var), NULL));
}

static void
_vala_Export_free_function_content_of (gpointer data)
{
	Export* self;
	self = *((Export**) data);
	_export_unref0_ (self);
}

Exports*
exports_construct (GType object_type,
                   gboolean save_settings)
{
	Exports* self = NULL;
	GArray* _tmp0_;
	ExportCSV* _tmp1_;
	ExportCSV* _tmp2_;
	ExportFileSystem* _tmp3_;
	ExportFileSystem* _tmp4_;
	ExportFreemind* _tmp5_;
	ExportFreemind* _tmp6_;
	ExportFreeplane* _tmp7_;
	ExportFreeplane* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar** _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	ExportImage* _tmp13_;
	ExportImage* _tmp14_;
	ExportMarkdown* _tmp15_;
	ExportMarkdown* _tmp16_;
	ExportMermaid* _tmp17_;
	ExportMermaid* _tmp18_;
	ExportOPML* _tmp19_;
	ExportOPML* _tmp20_;
	ExportOrgMode* _tmp21_;
	ExportOrgMode* _tmp22_;
	ExportOutliner* _tmp23_;
	ExportOutliner* _tmp24_;
	ExportPDF* _tmp25_;
	ExportPDF* _tmp26_;
	ExportPNG* _tmp27_;
	ExportPNG* _tmp28_;
	ExportPlantUML* _tmp29_;
	ExportPlantUML* _tmp30_;
	ExportPortableMinder* _tmp31_;
	ExportPortableMinder* _tmp32_;
	ExportSVG* _tmp33_;
	ExportSVG* _tmp34_;
	ExportText* _tmp35_;
	ExportText* _tmp36_;
	ExportWebP* _tmp37_;
	ExportWebP* _tmp38_;
	ExportXMind8* _tmp39_;
	ExportXMind8* _tmp40_;
	ExportXMind2021* _tmp41_;
	ExportXMind2021* _tmp42_;
	ExportYed* _tmp43_;
	ExportYed* _tmp44_;
	self = (Exports*) g_type_create_instance (object_type);
	_tmp0_ = g_array_new (TRUE, TRUE, sizeof (Export*));
	g_array_set_clear_func (_tmp0_, (GDestroyNotify) _vala_Export_free_function_content_of);
	_g_array_unref0 (self->priv->_exports);
	self->priv->_exports = _tmp0_;
	_tmp1_ = export_csv_new ();
	_tmp2_ = _tmp1_;
	exports_add (self, (Export*) _tmp2_, save_settings);
	_export_unref0 (_tmp2_);
	_tmp3_ = export_file_system_new ();
	_tmp4_ = _tmp3_;
	exports_add (self, (Export*) _tmp4_, save_settings);
	_export_unref0 (_tmp4_);
	_tmp5_ = export_freemind_new ();
	_tmp6_ = _tmp5_;
	exports_add (self, (Export*) _tmp6_, save_settings);
	_export_unref0 (_tmp6_);
	_tmp7_ = export_freeplane_new ();
	_tmp8_ = _tmp7_;
	exports_add (self, (Export*) _tmp8_, save_settings);
	_export_unref0 (_tmp8_);
	_tmp9_ = g_strdup (".jpg");
	_tmp10_ = g_strdup (".jpeg");
	_tmp11_ = g_new0 (gchar*, 2 + 1);
	_tmp11_[0] = _tmp9_;
	_tmp11_[1] = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp12__length1 = 2;
	_tmp13_ = export_image_new ("jpeg", _ ("JPEG"), _tmp12_, 2);
	_tmp14_ = _tmp13_;
	exports_add (self, (Export*) _tmp14_, save_settings);
	_export_unref0 (_tmp14_);
	_tmp12_ = (_vala_array_free (_tmp12_, _tmp12__length1, (GDestroyNotify) g_free), NULL);
	_tmp15_ = export_markdown_new ();
	_tmp16_ = _tmp15_;
	exports_add (self, (Export*) _tmp16_, save_settings);
	_export_unref0 (_tmp16_);
	_tmp17_ = export_mermaid_new ();
	_tmp18_ = _tmp17_;
	exports_add (self, (Export*) _tmp18_, save_settings);
	_export_unref0 (_tmp18_);
	_tmp19_ = export_opml_new ();
	_tmp20_ = _tmp19_;
	exports_add (self, (Export*) _tmp20_, save_settings);
	_export_unref0 (_tmp20_);
	_tmp21_ = export_org_mode_new ();
	_tmp22_ = _tmp21_;
	exports_add (self, (Export*) _tmp22_, save_settings);
	_export_unref0 (_tmp22_);
	_tmp23_ = export_outliner_new ();
	_tmp24_ = _tmp23_;
	exports_add (self, (Export*) _tmp24_, save_settings);
	_export_unref0 (_tmp24_);
	_tmp25_ = export_pdf_new ();
	_tmp26_ = _tmp25_;
	exports_add (self, (Export*) _tmp26_, save_settings);
	_export_unref0 (_tmp26_);
	_tmp27_ = export_png_new ();
	_tmp28_ = _tmp27_;
	exports_add (self, (Export*) _tmp28_, save_settings);
	_export_unref0 (_tmp28_);
	_tmp29_ = export_plant_uml_new ();
	_tmp30_ = _tmp29_;
	exports_add (self, (Export*) _tmp30_, save_settings);
	_export_unref0 (_tmp30_);
	_tmp31_ = export_portable_minder_new ();
	_tmp32_ = _tmp31_;
	exports_add (self, (Export*) _tmp32_, save_settings);
	_export_unref0 (_tmp32_);
	_tmp33_ = export_svg_new ();
	_tmp34_ = _tmp33_;
	exports_add (self, (Export*) _tmp34_, save_settings);
	_export_unref0 (_tmp34_);
	_tmp35_ = export_text_new ();
	_tmp36_ = _tmp35_;
	exports_add (self, (Export*) _tmp36_, save_settings);
	_export_unref0 (_tmp36_);
	_tmp37_ = export_web_p_new ();
	_tmp38_ = _tmp37_;
	exports_add (self, (Export*) _tmp38_, save_settings);
	_export_unref0 (_tmp38_);
	_tmp39_ = export_xmind8_new ();
	_tmp40_ = _tmp39_;
	exports_add (self, (Export*) _tmp40_, save_settings);
	_export_unref0 (_tmp40_);
	_tmp41_ = export_xmind2021_new ();
	_tmp42_ = _tmp41_;
	exports_add (self, (Export*) _tmp42_, save_settings);
	_export_unref0 (_tmp42_);
	_tmp43_ = export_yed_new ();
	_tmp44_ = _tmp43_;
	exports_add (self, (Export*) _tmp44_, save_settings);
	_export_unref0 (_tmp44_);
	return self;
}

Exports*
exports_new (gboolean save_settings)
{
	return exports_construct (TYPE_EXPORTS, save_settings);
}

static void
___lambda243_ (Exports* self)
{
	exports_save (self);
}

static void
____lambda243__export_settings_changed (Export* _sender,
                                        gpointer self)
{
	___lambda243_ ((Exports*) self);
}

static gpointer
_export_ref0 (gpointer self)
{
	return self ? export_ref (self) : NULL;
}

static void
exports_add (Exports* self,
             Export* export,
             gboolean save_settings)
{
	GArray* _tmp0_;
	Export* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (export != NULL);
	if (save_settings) {
		g_signal_connect (export, "settings-changed", (GCallback) ____lambda243__export_settings_changed, self);
	}
	_tmp0_ = self->priv->_exports;
	_tmp1_ = _export_ref0 (export);
	g_array_append_val (_tmp0_, _tmp1_);
}

gint
exports_length (Exports* self)
{
	GArray* _tmp0_;
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	_tmp0_ = self->priv->_exports;
	result = (gint) _tmp0_->len;
	return result;
}

Export*
exports_index (Exports* self,
               gint idx)
{
	GArray* _tmp0_;
	Export* _tmp1_;
	Export* _tmp2_;
	Export* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_exports;
	_tmp1_ = g_array_index (_tmp0_, Export*, (guint) idx);
	_tmp2_ = _export_ref0 (_tmp1_);
	result = _tmp2_;
	return result;
}

Export*
exports_get_by_name (Exports* self,
                     const gchar* name)
{
	Export* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				GArray* _tmp2_;
				GArray* _tmp3_;
				Export* _tmp4_;
				const gchar* _tmp5_;
				const gchar* _tmp6_;
				if (!_tmp0_) {
					gint _tmp1_;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = self->priv->_exports;
				if (!(((guint) i) < _tmp2_->len)) {
					break;
				}
				_tmp3_ = self->priv->_exports;
				_tmp4_ = g_array_index (_tmp3_, Export*, (guint) i);
				_tmp5_ = export_get_name (_tmp4_);
				_tmp6_ = _tmp5_;
				if (g_strcmp0 (_tmp6_, name) == 0) {
					GArray* _tmp7_;
					Export* _tmp8_;
					Export* _tmp9_;
					_tmp7_ = self->priv->_exports;
					_tmp8_ = g_array_index (_tmp7_, Export*, (guint) i);
					_tmp9_ = _export_ref0 (_tmp8_);
					result = _tmp9_;
					return result;
				}
			}
		}
	}
	result = NULL;
	return result;
}

gint
exports_get_index_by_name (Exports* self,
                           const gchar* name)
{
	gint result;
	g_return_val_if_fail (self != NULL, -1);
	g_return_val_if_fail (name != NULL, -1);
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				GArray* _tmp2_;
				GArray* _tmp3_;
				Export* _tmp4_;
				const gchar* _tmp5_;
				const gchar* _tmp6_;
				if (!_tmp0_) {
					gint _tmp1_;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = self->priv->_exports;
				if (!(((guint) i) < _tmp2_->len)) {
					break;
				}
				_tmp3_ = self->priv->_exports;
				_tmp4_ = g_array_index (_tmp3_, Export*, (guint) i);
				_tmp5_ = export_get_name (_tmp4_);
				_tmp6_ = _tmp5_;
				if (g_strcmp0 (_tmp6_, name) == 0) {
					result = i;
					return result;
				}
			}
		}
	}
	result = -1;
	return result;
}

static gchar*
exports_settings_file (Exports* self,
                       gboolean make_dir)
{
	gchar* dir = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_get_user_data_dir ();
	_tmp1_ = g_build_filename (_tmp0_, "minder", NULL);
	dir = _tmp1_;
	if (make_dir) {
		const gchar* _tmp3_;
		_tmp3_ = dir;
		_tmp2_ = g_mkdir_with_parents (_tmp3_, 0775) != 0;
	} else {
		_tmp2_ = FALSE;
	}
	if (_tmp2_) {
		result = NULL;
		_g_free0 (dir);
		return result;
	}
	_tmp4_ = dir;
	_tmp5_ = g_build_filename (_tmp4_, "exports.xml", NULL);
	result = _tmp5_;
	_g_free0 (dir);
	return result;
}

void
exports_save (Exports* self)
{
	gchar* sfile = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	xmlDoc* doc = NULL;
	xmlDoc* _tmp2_;
	xmlNode* root = NULL;
	xmlNode* _tmp3_;
	xmlNode* _tmp4_;
	const gchar* _tmp5_;
	xmlDoc* _tmp6_;
	xmlNode* _tmp7_;
	xmlDoc* _tmp15_;
	const gchar* _tmp16_;
	xmlDoc* _tmp17_;
	g_return_if_fail (self != NULL);
	_tmp0_ = exports_settings_file (self, TRUE);
	sfile = _tmp0_;
	_tmp1_ = sfile;
	if (_tmp1_ == NULL) {
		_g_free0 (sfile);
		return;
	}
	_tmp2_ = xmlNewDoc ((xmlChar*) "1.0");
	doc = _tmp2_;
	_tmp3_ = xmlNewNode (NULL, (xmlChar*) "exports");
	root = _tmp3_;
	_tmp4_ = root;
	_tmp5_ = minder_version;
	xmlSetProp (_tmp4_, (xmlChar*) "version", (xmlChar*) _tmp5_);
	_tmp6_ = doc;
	_tmp7_ = root;
	xmlDocSetRootElement (_tmp6_, _tmp7_);
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp8_ = FALSE;
			_tmp8_ = TRUE;
			while (TRUE) {
				GArray* _tmp10_;
				xmlNode* _tmp11_;
				GArray* _tmp12_;
				Export* _tmp13_;
				xmlNode* _tmp14_;
				if (!_tmp8_) {
					gint _tmp9_;
					_tmp9_ = i;
					i = _tmp9_ + 1;
				}
				_tmp8_ = FALSE;
				_tmp10_ = self->priv->_exports;
				if (!(((guint) i) < _tmp10_->len)) {
					break;
				}
				_tmp11_ = root;
				_tmp12_ = self->priv->_exports;
				_tmp13_ = g_array_index (_tmp12_, Export*, (guint) i);
				_tmp14_ = export_save (_tmp13_);
				xmlAddChild (_tmp11_, _tmp14_);
			}
		}
	}
	_tmp15_ = doc;
	_tmp16_ = sfile;
	xmlSaveFormatFile (_tmp16_, _tmp15_, 1);
	_tmp17_ = doc;
	_xmlFreeDoc0 (_tmp17_);
	_g_free0 (sfile);
}

void
exports_load (Exports* self)
{
	gchar* sfile = NULL;
	gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	xmlDoc* doc = NULL;
	const gchar* _tmp4_;
	xmlDoc* _tmp5_;
	xmlDoc* _tmp6_;
	xmlDoc* _tmp31_;
	g_return_if_fail (self != NULL);
	_tmp0_ = exports_settings_file (self, FALSE);
	sfile = _tmp0_;
	_tmp2_ = sfile;
	if (_tmp2_ == NULL) {
		_tmp1_ = TRUE;
	} else {
		const gchar* _tmp3_;
		_tmp3_ = sfile;
		_tmp1_ = !g_file_test (_tmp3_, G_FILE_TEST_EXISTS);
	}
	if (_tmp1_) {
		_g_free0 (sfile);
		return;
	}
	_tmp4_ = sfile;
	_tmp5_ = xmlReadFile (_tmp4_, NULL, (gint) XML_PARSE_HUGE);
	doc = _tmp5_;
	_tmp6_ = doc;
	if (_tmp6_ == NULL) {
		_g_free0 (sfile);
		return;
	}
	{
		xmlNode* it = NULL;
		xmlDoc* _tmp7_;
		xmlNode* _tmp8_;
		xmlNode* _tmp9_;
		_tmp7_ = doc;
		_tmp8_ = xmlDocGetRootElement (_tmp7_);
		_tmp9_ = _tmp8_->children;
		it = _tmp9_;
		{
			gboolean _tmp10_ = FALSE;
			_tmp10_ = TRUE;
			while (TRUE) {
				xmlNode* _tmp13_;
				gboolean _tmp14_ = FALSE;
				xmlNode* _tmp15_;
				if (!_tmp10_) {
					xmlNode* _tmp11_;
					xmlNode* _tmp12_;
					_tmp11_ = it;
					_tmp12_ = _tmp11_->next;
					it = _tmp12_;
				}
				_tmp10_ = FALSE;
				_tmp13_ = it;
				if (!(_tmp13_ != NULL)) {
					break;
				}
				_tmp15_ = it;
				if (_tmp15_->type == XML_ELEMENT_NODE) {
					xmlNode* _tmp16_;
					const gchar* _tmp17_;
					_tmp16_ = it;
					_tmp17_ = _tmp16_->name;
					_tmp14_ = g_strcmp0 (_tmp17_, "export") == 0;
				} else {
					_tmp14_ = FALSE;
				}
				if (_tmp14_) {
					gchar* export_name = NULL;
					xmlNode* _tmp18_;
					gchar* _tmp19_;
					_tmp18_ = it;
					_tmp19_ = (gchar*) xmlGetProp (_tmp18_, (xmlChar*) "name");
					export_name = _tmp19_;
					{
						gint i = 0;
						i = 0;
						{
							gboolean _tmp20_ = FALSE;
							_tmp20_ = TRUE;
							while (TRUE) {
								GArray* _tmp22_;
								GArray* _tmp23_;
								Export* _tmp24_;
								const gchar* _tmp25_;
								const gchar* _tmp26_;
								const gchar* _tmp27_;
								if (!_tmp20_) {
									gint _tmp21_;
									_tmp21_ = i;
									i = _tmp21_ + 1;
								}
								_tmp20_ = FALSE;
								_tmp22_ = self->priv->_exports;
								if (!(((guint) i) < _tmp22_->len)) {
									break;
								}
								_tmp23_ = self->priv->_exports;
								_tmp24_ = g_array_index (_tmp23_, Export*, (guint) i);
								_tmp25_ = export_get_name (_tmp24_);
								_tmp26_ = _tmp25_;
								_tmp27_ = export_name;
								if (g_strcmp0 (_tmp26_, _tmp27_) == 0) {
									GArray* _tmp28_;
									Export* _tmp29_;
									xmlNode* _tmp30_;
									_tmp28_ = self->priv->_exports;
									_tmp29_ = g_array_index (_tmp28_, Export*, (guint) i);
									_tmp30_ = it;
									export_load (_tmp29_, _tmp30_);
									break;
								}
							}
						}
					}
					_g_free0 (export_name);
				}
			}
		}
	}
	_tmp31_ = doc;
	_xmlFreeDoc0 (_tmp31_);
	_g_free0 (sfile);
}

static void
value_exports_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
value_exports_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		exports_unref (value->data[0].v_pointer);
	}
}

static void
value_exports_copy_value (const GValue* src_value,
                          GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = exports_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
value_exports_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
value_exports_collect_value (GValue* value,
                             guint n_collect_values,
                             GTypeCValue* collect_values,
                             guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		Exports * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = exports_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
value_exports_lcopy_value (const GValue* value,
                           guint n_collect_values,
                           GTypeCValue* collect_values,
                           guint collect_flags)
{
	Exports ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = exports_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
param_spec_exports (const gchar* name,
                    const gchar* nick,
                    const gchar* blurb,
                    GType object_type,
                    GParamFlags flags)
{
	ParamSpecExports* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_EXPORTS), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
value_get_exports (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_EXPORTS), NULL);
	return value->data[0].v_pointer;
}

void
value_set_exports (GValue* value,
                   gpointer v_object)
{
	Exports * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_EXPORTS));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_EXPORTS));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		exports_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		exports_unref (old);
	}
}

void
value_take_exports (GValue* value,
                    gpointer v_object)
{
	Exports * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_EXPORTS));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_EXPORTS));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		exports_unref (old);
	}
}

static void
exports_class_init (ExportsClass * klass,
                    gpointer klass_data)
{
	exports_parent_class = g_type_class_peek_parent (klass);
	((ExportsClass *) klass)->finalize = exports_finalize;
	g_type_class_adjust_private_offset (klass, &Exports_private_offset);
}

static void
exports_instance_init (Exports * self,
                       gpointer klass)
{
	self->priv = exports_get_instance_private (self);
	self->ref_count = 1;
}

static void
exports_finalize (Exports * obj)
{
	Exports * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EXPORTS, Exports);
	g_signal_handlers_destroy (self);
	_g_array_unref0 (self->priv->_exports);
}

static GType
exports_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { value_exports_init, value_exports_free_value, value_exports_copy_value, value_exports_peek_pointer, "p", value_exports_collect_value, "p", value_exports_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (ExportsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) exports_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Exports), 0, (GInstanceInitFunc) exports_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType exports_type_id;
	exports_type_id = g_type_register_fundamental (g_type_fundamental_next (), "Exports", &g_define_type_info, &g_define_type_fundamental_info, 0);
	Exports_private_offset = g_type_add_instance_private (exports_type_id, sizeof (ExportsPrivate));
	return exports_type_id;
}

GType
exports_get_type (void)
{
	static volatile gsize exports_type_id__once = 0;
	if (g_once_init_enter (&exports_type_id__once)) {
		GType exports_type_id;
		exports_type_id = exports_get_type_once ();
		g_once_init_leave (&exports_type_id__once, exports_type_id);
	}
	return exports_type_id__once;
}

gpointer
exports_ref (gpointer instance)
{
	Exports * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
exports_unref (gpointer instance)
{
	Exports * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		EXPORTS_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

